@@ -34,6 +34,8 @@ define([
 	'orion/status',
 	'orion/progress',
 	'orion/operationsClient',
+	'orion/git/gitClient',
+	'orion/ssh/sshTools', 
 	'orion/outliner',
 	'orion/dialogs',
 	'orion/extensionCommands',
@@ -51,17 +53,19 @@ define([
 	'orion/webui/splitter',
 	'orion/webui/tooltip',
 	'orion/webui/contextmenu',
+	'orion/webui/menubar',
 	'orion/bidiUtils',
 	'orion/customGlobalCommands',
 	'orion/generalPreferences',
 	'orion/breadcrumbs',
-	'orion/keyBinding'
+	'orion/keyBinding',
+	'orion/urlModifier'
 ], function(
 	messages, Sidebar, mInputManager, mCommands, mGlobalCommands,
 	mTextModelFactory, mUndoStack,
 	mFolderView, mEditorView, mPluginEditorView , mMarkdownView, mMarkdownEditor,
-	mCommandRegistry, mContentTypes, mFileClient, mFileCommands, mEditorCommands, mSelection, mStatus, mProgress, mOperationsClient, mOutliner, mDialogs, mExtensionCommands, ProjectCommands, mSearchClient,
-	EventTarget, URITemplate, i18nUtil, PageUtil, util, objects, lib, Deferred, mProjectClient, mSplitter, mTooltip, mContextMenu, bidiUtils, mCustomGlobalCommands, mGeneralPrefs, mBreadcrumbs, mKeyBinding
+	mCommandRegistry, mContentTypes, mFileClient, mFileCommands, mEditorCommands, mSelection, mStatus, mProgress, mOperationsClient, mGitClient, mSshTools, mOutliner, mDialogs, mExtensionCommands, ProjectCommands, mSearchClient,
+	EventTarget, URITemplate, i18nUtil, PageUtil, util, objects, lib, Deferred, mProjectClient, mSplitter, mTooltip, mContextMenu, mMenuBar, bidiUtils, mCustomGlobalCommands, mGeneralPrefs, mBreadcrumbs, mKeyBinding, urlModifier
 ) {
 
 var exports = {};
@@ -83,10 +87,8 @@ function MenuBar(options) {
 	this.fileClient = options.fileClient;
 	this.editorCommands = options.editorCommands;
 	this.parentNode = options.parentNode;
-	this.fileActionsScope = "fileActions"; //$NON-NLS-0$
-	this.editActionsScope = "editActions"; //$NON-NLS-0$
-	this.viewActionsScope = "viewActions"; //$NON-NLS-0$
-	this.toolsActionsScope = "toolsActions"; //$NON-NLS-0$
+	this.menuBarActionScope = "menuBarActions";
+	this.toolsActionsScope = "menuBarActions"; //$NON-NLS-0$
 	this.additionalActionsScope = "extraActions"; //$NON-NLS-0$
 	this.createActionSections();
 	
@@ -96,7 +98,7 @@ MenuBar.prototype = {};
 objects.mixin(MenuBar.prototype, {
 	createActionSections: function() {
 		var _self = this;
-		[this.fileActionsScope, this.editActionsScope, this.viewActionsScope, this.toolsActionsScope, this.additionalActionsScope].reverse().forEach(function(id) {
+		[this.additionalActionsScope].reverse().forEach(function(id) {
 			if (!_self[id]) {
 				var elem = document.createElement("ul"); //$NON-NLS-0$
 				elem.id = id;
@@ -111,20 +113,31 @@ objects.mixin(MenuBar.prototype, {
 			}
 		});
 
+		// Create the main menu bar
+		var editMenuBar = document.createElement("ul"); //$NON-NLS-0$
+		var menuBarScope = editMenuBar.id = this.menuBarActionScope;
+		editMenuBar.setAttribute("role", "menubar");
+		var menuBar = new mMenuBar.MenuBar({
+			dropdown: editMenuBar,
+		});
+		
+		
+		editMenuBar.classList.add("layoutLeft"); //$NON-NLS-0$
+		editMenuBar.classList.add("commandList"); //$NON-NLS-0$
+		editMenuBar.classList.add("pageActions"); //$NON-NLS-0$
+		_self.parentNode.insertBefore(editMenuBar, _self.parentNode.firstChild);
+
 		var commandRegistry = this.commandRegistry;
-		var fileActionsScope = this.fileActionsScope;
-		var editActionsScope = this.editActionsScope;
-		var viewActionsScope = this.viewActionsScope;
 		var toolsActionsScope = this.toolsActionsScope;
 		
-		commandRegistry.addCommandGroup(fileActionsScope, "orion.menuBarFileGroup", 1000, messages["File"], null, messages["noActions"], null, null, "dropdownSelection"); //$NON-NLS-3$ //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
-		commandRegistry.addCommandGroup(editActionsScope, "orion.menuBarEditGroup", 100, messages["Edit"], null, messages["noActions"], null, null, "dropdownSelection"); //$NON-NLS-3$ //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
-		commandRegistry.addCommandGroup(viewActionsScope, "orion.menuBarViewGroup", 100, messages["View"], null, messages["noActions"], null, null, "dropdownSelection"); //$NON-NLS-1$ //$NON-NLS-2$
-		commandRegistry.addCommandGroup(toolsActionsScope, "orion.menuBarToolsGroup", 100, messages["Tools"], null, null, null, null, "dropdownSelection"); //$NON-NLS-1$ //$NON-NLS-2$
+		commandRegistry.addCommandGroup(menuBarScope, "orion.menuBarFileGroup", 1, messages["File"], null, messages["noActions"], null, null, "dropdownSelection"); //$NON-NLS-3$ //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
+		commandRegistry.addCommandGroup(menuBarScope, "orion.menuBarEditGroup", 2, messages["Edit"], null, messages["noActions"], null, null, "dropdownSelection"); //$NON-NLS-3$ //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
+		commandRegistry.addCommandGroup(menuBarScope, "orion.menuBarViewGroup", 3, messages["View"], null, messages["noActions"], null, null, "dropdownSelection"); //$NON-NLS-1$ //$NON-NLS-2$
+		commandRegistry.addCommandGroup(menuBarScope, "orion.menuBarToolsGroup", 4, messages["Tools"], null, null, null, null, "dropdownSelection"); //$NON-NLS-1$ //$NON-NLS-2$
 		
-		commandRegistry.addCommandGroup(fileActionsScope, "orion.newContentGroup", 0, messages["New"], "orion.menuBarFileGroup", null, null, null, "dropdownSelection"); //$NON-NLS-3$ //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
-		commandRegistry.addCommandGroup(fileActionsScope, "orion.importGroup", 100, messages["Import"], "orion.menuBarFileGroup", null, null, null, "dropdownSelection"); //$NON-NLS-3$ //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
-		commandRegistry.addCommandGroup(fileActionsScope, "orion.exportGroup", 1001, messages["Export"], "orion.menuBarFileGroup", null, null, null, "dropdownSelection"); //$NON-NLS-3$ //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
+		commandRegistry.addCommandGroup(menuBarScope, "orion.newContentGroup", 0, messages["New"], "orion.menuBarFileGroup", null, null, null, "dropdownSelection"); //$NON-NLS-3$ //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
+		commandRegistry.addCommandGroup(menuBarScope, "orion.importGroup", 100, messages["Import"], "orion.menuBarFileGroup", null, null, null, "dropdownSelection"); //$NON-NLS-3$ //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
+		commandRegistry.addCommandGroup(menuBarScope, "orion.exportGroup", 1001, messages["Export"], "orion.menuBarFileGroup", null, null, null, "dropdownSelection"); //$NON-NLS-3$ //$NON-NLS-2$ //$NON-NLS-1$ //$NON-NLS-0$
 	},
 	createCommands: function() {
 		var serviceRegistry = this.serviceRegistry;
@@ -169,14 +182,10 @@ objects.mixin(MenuBar.prototype, {
 			this.editorCommands.updateCommands(editorViewer.getCurrentEditorView());
 		}
 		var commandRegistry = this.commandRegistry, serviceRegistry = this.serviceRegistry;
-		commandRegistry.registerSelectionService(this.fileActionsScope, visible ? selection : null);
-		commandRegistry.registerSelectionService(this.editActionsScope, visible ? selection : null);
-		commandRegistry.registerSelectionService(this.viewActionsScope, visible ? selection : null);
+		commandRegistry.registerSelectionService(this.menuBarActionScope, visible ? selection : null);
 		mFileCommands.setExplorer(explorer);
 		ProjectCommands.setExplorer(explorer);
-		mFileCommands.updateNavTools(serviceRegistry, commandRegistry, explorer, null, [this.fileActionsScope, this.editActionsScope, this.viewActionsScope], treeRoot, true);
-		commandRegistry.destroy(this.toolsActionsScope);
-		commandRegistry.renderCommands(this.toolsActionsScope, this.toolsActionsScope, metadata, explorer, "tool"); //$NON-NLS-0$
+		mFileCommands.updateNavTools(serviceRegistry, commandRegistry, explorer, null, [this.menuBarActionScope], treeRoot, true);
 		commandRegistry.destroy(this.additionalActionsScope);
 		commandRegistry.renderCommands(this.additionalActionsScope, this.additionalActionsScope, treeRoot, explorer, "button"); //$NON-NLS-0$
 	}
@@ -356,7 +365,7 @@ objects.mixin(TabWidget.prototype, {
 		this.dispatchEvent(closingEvent);
 	},
 	setWindowLocation: function(href) {
-		window.location = href;
+		window.location = urlModifier(href);
 	},
 	dragenterListener_: function(e) {
 		e.preventDefault();
@@ -432,7 +441,15 @@ objects.mixin(TabWidget.prototype, {
 	setTabStorage: function() {
 		var mappedFiles = this.fileList.map(function(f) {
 			if (!f.metadata.Directory) {
-				return {metadata: {Location: f.metadata.Location, Name: f.metadata.Name, WorkspaceLocation: f.metadata.WorkspaceLocation, Directory: f.metadata.Directory, Parents: f.metadata.Parents}, href: f.href, isTransient: f.isTransient};
+				var parents = f.metadata.Parents.map(function(each){
+					return {
+						Name: each.Name,
+						Location: each.Location,
+						ChildrenLocation: each.ChildrenLocation,
+						WorkspaceLocation: each.WorkspaceLocation
+					};
+				});
+				return {metadata: {Location: f.metadata.Location, Name: f.metadata.Name, WorkspaceLocation: f.metadata.WorkspaceLocation, Directory: f.metadata.Directory, Parents: parents}, href: f.href, isTransient: f.isTransient};
 			}
 		});
 		sessionStorage["editorTabs_" + this.id] = JSON.stringify(mappedFiles);
@@ -605,12 +622,12 @@ objects.mixin(TabWidget.prototype, {
 	transientToPermenant: function(href){
 		var hrefHash = href && href.split("#")[1];
 		if(this.transientTab && hrefHash && hrefHash.indexOf(this.transientTab.location) === 0){
-			this.fileList.find(function(file){
-				if(hrefHash.indexOf(file.metadata.Location) === 0){
+			this.fileList.some(function(file) {
+				if (hrefHash.indexOf(file.metadata.Location) === 0) {
 					file.isTransient = false;
 					return true;
 				}
-			})
+			});
 			this.transientTab && this.transientTab.editorTabNode.classList.remove("transient");
 			this.transientTab = null;
 		}
@@ -948,12 +965,12 @@ objects.mixin(EditorViewer.prototype, {
 			callback: function(commandInvocation) {
 				// Get the right hand tabs from this.editorTab parent.
 				var firstNodeIndexToRemove;
-				Array.prototype.find.call(this.tabWidget.editorTabContainer.childNodes, function(node, index){
+				Array.prototype.some.call(this.tabWidget.editorTabContainer.childNodes, function(node, index){
 					if(node.metadata.Location === commandInvocation.items.Location){
 						firstNodeIndexToRemove = index + 1;
 						return true;
 					}
-				})
+				});
 				var closingButtons = [];
 				for(var j = firstNodeIndexToRemove; j < this.tabWidget.editorTabContainer.childNodes.length; j++){
 					var closeButton = this.tabWidget.editorTabContainer.childNodes[j].querySelector(".editorTabCloseButton");
@@ -1067,7 +1084,7 @@ objects.mixin(EditorViewer.prototype, {
 			});
 		}.bind(this));
 	},
-
+	
 	createInputManager: function() {
 		var inputManager = this.inputManager = new mInputManager.InputManager({
 			serviceRegistry: this.serviceRegistry,
@@ -1088,7 +1105,7 @@ objects.mixin(EditorViewer.prototype, {
 			isUnsavedWarningNeeed:function(){
 				return this.getOpenEditorCount(this.inputManager.getFileMetadata()) === 1;
 			}.bind(this)
-		});
+		});	
 		inputManager.addEventListener("InputChanged", function(evt) { //$NON-NLS-0$
 			var metadata = evt.metadata;
 			if (metadata) {
@@ -1104,13 +1121,27 @@ objects.mixin(EditorViewer.prototype, {
 			this.updateDirtyIndicator();
 			evt.editor = this.editor;
 			this.pool.metadata = metadata;
-			this.pool.model.addEventListener("postChanged", function(evt){
-				if(this.pool.undoStack._unsavedChanges && this.pool.undoStack._unsavedChanges.length > 0){
-					if(this.tabWidget.transientTab && this.tabWidget.transientTab.location === this.pool.metadata.Location){
-						this.tabWidget.transientToPermenant(this.tabWidget.transientTab.href);
+			
+			var editorView = this.getCurrentEditorView();
+			if (editorView && editorView.editor) {
+				this.editor.isFileInitiallyLoaded = false;
+				var textView = editorView.editor.getTextView();
+				textView.addEventListener("ModelChanged", function(){
+					if(this.editor.isFileInitiallyLoaded){
+						if(this.tabWidget.transientTab && this.tabWidget.transientTab.location === this.pool.metadata.Location){
+							this.tabWidget.transientToPermenant(this.tabWidget.transientTab.href);
+						}
 					}
-				}
-			}.bind(this));
+				}.bind(this));
+				var flagInitialLoad = function(evt){
+						if(typeof evt.contentsSaved === "undefined"){
+							this.editor.isFileInitiallyLoaded = true; 
+						}
+						this.editor.removeEventListener("InputChanged", flagInitialLoad);
+					}.bind(this);
+				this.editor.addEventListener("InputChanged", flagInitialLoad);
+			}
+			
 			if (this.shown) {
 				var href = window.location.href;
 				this.activateContext.setActiveEditorViewer(this);
@@ -1372,6 +1403,8 @@ objects.mixin(EditorSetup.prototype, {
 		this.dialogService = new mDialogs.DialogService(serviceRegistry);
 		this.commandRegistry = new mCommandRegistry.CommandRegistry({selection: this.selection});
 		this.progressService = new mProgress.ProgressService(serviceRegistry, this.operationsClient, this.commandRegistry);
+		this.sshService = new mSshTools.SshService(serviceRegistry);
+		this.gitClient = new mGitClient.GitService(serviceRegistry);
 		
 		// Editor needs additional services
 		this.outlineService = new mOutliner.OutlineService({serviceRegistry: serviceRegistry, preferences: this.preferences});
@@ -1387,9 +1420,9 @@ objects.mixin(EditorSetup.prototype, {
 			renderToolbars: this.renderToolbars.bind(this),
 			searcher: this.searcher,
 			readonly: this.readonly,
-			toolbarId: "toolsActions", //$NON-NLS-0$
-			saveToolbarId: "fileActions", //$NON-NLS-0$
-			editToolbarId: "editActions", //$NON-NLS-0$
+			toolbarId: "menuBarActions", //$NON-NLS-0$
+			saveToolbarId: "menuBarActions", //$NON-NLS-0$
+			editToolbarId: "menuBarActions", //$NON-NLS-0$
 			navToolbarId: "pageNavigationActions", //$NON-NLS-0$
 			editorContextMenuId: "editorContextMenuActions", //$NON-NLS-0$
 		});
@@ -1493,9 +1526,9 @@ objects.mixin(EditorSetup.prototype, {
 			selection: this.selection,
 			serviceRegistry: this.serviceRegistry,
 			sidebarNavInputManager: this.sidebarNavInputManager,
-			switcherScope: "viewActions", //$NON-NLS-0$
-			editScope: "editActions", //$NON-NLS-0$
-			toolsScope: "toolsActions", //$NON-NLS-0$
+			switcherScope: "menuBarActions", //$NON-NLS-0$
+			editScope: "menuBarActions", //$NON-NLS-0$
+			toolsScope: "menuBarActions", //$NON-NLS-0$
 			menuBar: this.menuBar,
 			toolbar: this.sidebarToolbar
 		});
@@ -1531,7 +1564,7 @@ objects.mixin(EditorSetup.prototype, {
 		}.bind(this));
 		this.sidebarNavInputManager.addEventListener("create", function(evt) { //$NON-NLS-0$
 			if (evt.newValue && !evt.ignoreRedirect) {
-				window.location = this.computeNavigationHref(evt.newValue);
+				window.location = urlModifier(this.computeNavigationHref(evt.newValue));
 			}
 		}.bind(this));
 	},
@@ -1592,11 +1625,11 @@ objects.mixin(EditorSetup.prototype, {
 				if (hash === window.location.hash.substring(1)) {
 					this.activeEditorViewer.inputManager.setInput(hash);
 				} else {
-					window.location = href;
+					window.location = urlModifier(href);
 				}
 				break;
 			case 'tab':
-				window.open(href);
+				window.open(urlModifier(href));
 				break;
 			case 'split':
 				var locWithParams = href.split('#')[1];
