@@ -31,11 +31,6 @@ define([
 					fieldTitle: messages["filteredResourcesTooltip"],
 					postChange: this.setPreferences.bind(this)
 				});
-				this.enableWorkspaces = new SettingsCheckbox({
-					fieldlabel: "Enable Multiple Workspaces:",
-					fieldTitle: "Allow the creation of multiple workspaces per user.",
-					postChange: this.setPreferences.bind(this)
-				});
 				this.enableEditorTabs = new SettingsCheckbox({
 					fieldlabel: messages["enableEditorTabs"],
 					fieldTitle: messages["enableEditorTabsTooltip"],
@@ -44,6 +39,8 @@ define([
 				this.maximumEditorTabsTextfield = new SettingsTextfield({
 					fieldlabel: messages["maximumEditorTabs"],
 					fieldTitle: messages["maximumEditorTabsTooltip"],
+					fieldType: "number",
+					fieldMin: 0,
 					postChange: this.setPreferences.bind(this)
 				});
 
@@ -61,7 +58,7 @@ define([
 					sectionName: messages["Files"],
 					parentNode: settingsContentElement,
 					children: util.isElectron ? [this.filteredResourcesTextfield] 
-					: [this.desktopSelectionPolicyCheckbox, this.filteredResourcesTextfield, this.enableWorkspaces]
+					: [this.desktopSelectionPolicyCheckbox, this.filteredResourcesTextfield]
 				});
 				fileSubsection.show();
 				var editorTabs = new Subsection({
@@ -85,9 +82,8 @@ define([
 					}else{
 						this.desktopSelectionPolicyCheckbox.enableCheckBox();
 					}
-					generalPrefs.enableWorkspaces = this.enableWorkspaces.isChecked();
 					var maxTabs = parseInt(this.maximumEditorTabsTextfield.getValue(), 10);
-					maxTabs = isNaN(maxTabs) ? 0 : maxTabs;
+					maxTabs = isNaN(maxTabs) || maxTabs< 0 ? 0 : maxTabs;
 					generalPrefs.maximumEditorTabs = maxTabs;
 					this.preferences.setPrefs(generalPrefs);
 				}.bind(this));
@@ -111,9 +107,6 @@ define([
 						}
 					}
 					
-					this.enableWorkspaces.setSelection(generalPrefs.enableWorkspaces);
-					this.enableWorkspaces.show();
-
 					//filtered resources
 					if(typeof generalPrefs.filteredResources !== 'string') {
 						this.filteredResourcesTextfield.setValue(".git, .DS_Store"); //default
